/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

#pragma once

#include <iostream>
#include <iterator>

#include "fmt/base.h"
#include "version.h"

inline std::string PrintVersion() {
  std::string result;
  if (VERSION != "unstable") {
    result += "version ";
  }

  result += VERSION;

  if (!GIT_COMMIT.empty()) {
    fmt::format_to(std::back_inserter(result), " (commit {})", GIT_COMMIT);
  }

  return result;
}
